package Test::Run::Drivers::CmdLineTestBare;

use strict;
use warnings;

use NEXT;

sub _initialize
{
    my $self = shift;
    $self->NEXT::_initialize(@_);
}

1;

